@@ -4,7 +4,7 @@
 /* SUMMARY
 /*	create or proxied database
 /* SYNOPSIS
-/*	#include <mkmap.h>
+/*	#include <dict_proxy.h>
 /*
 /*	MKMAP	*mkmap_proxy_open(path)
 /*	const char *path;
@@ -26,6 +26,11 @@
 /*	IBM T.J. Watson Research
 /*	P.O. Box 704
 /*	Yorktown Heights, NY 10598, USA
+/*
+/*	Wietse Venema
+/*	Google, Inc.
+/*	111 8th Avenue
+/*	New York, NY 10011, USA
 /*--*/
 
 /* System library. */
@@ -37,10 +42,6 @@
 #include <mymalloc.h>
 #include <dict_proxy.h>
 
-/* Application-specific. */
-
-#include "mkmap.h"
-
 /* mkmap_proxy_open - create or open database */
 
 MKMAP  *mkmap_proxy_open(const char *unused_path)
