@@ -46,14 +46,14 @@
 /*	of taking the names literally.
 /*
 /*	This feature is available in Postfix 2.0 and later.
-/*.IP \fB-r\fR
+/* .IP \fB-r\fR
 /*	Print records in file order, don't follow pointer records.
 /*
 /*	This feature is available in Postfix 3.7 and later.
-/* IP "\fB-s \fIoffset\fR"
+/* .IP "\fB-s \fIoffset\fR"
 /*	Skip to the specified queue file offset.
 /*
-/*	This feature is available in Postfix 2.0 and later.
+/*	This feature is available in Postfix 3.7 and later.
 /* .IP \fB-v\fR
 /*	Enable verbose logging for debugging purposes. Multiple \fB-v\fR
 /*	options make the software increasingly verbose.
@@ -193,19 +193,19 @@ static void postcat(VSTREAM *fp, VSTRING *buffer, int flags)
 	    for (offset = 0; offset < start_offset; offset++)
 		if (VSTREAM_GETC(fp) == VSTREAM_EOF)
 		    msg_fatal("%s: skip %ld bytes failed after %ld",
-			      VSTREAM_PATH(fp), start_offset, offset);
+			      VSTREAM_PATH(fp), (long) start_offset,
+			      (long) offset);
 	} else {
 	    if (vstream_fseek(fp, start_offset, SEEK_SET) < 0)
 		msg_fatal("%s: seek to %ld: %m",
-			  VSTREAM_PATH(fp), start_offset);
+			  VSTREAM_PATH(fp), (long) start_offset);
 	}
     }
 
     /*
      * See if this is a plausible file.
      */
-    if (start_offset == 0 && (flags & PC_FLAG_RAW) == 0
-	&& (ch = VSTREAM_GETC(fp)) != VSTREAM_EOF) {
+    if (start_offset == 0 && (ch = VSTREAM_GETC(fp)) != VSTREAM_EOF) {
 	if (!strchr(REC_TYPE_ENVELOPE, ch)) {
 	    msg_warn("%s: input is not a valid queue file", VSTREAM_PATH(fp));
 	    return;
@@ -339,6 +339,10 @@ static void postcat(VSTREAM *fp, VSTRING *buffer, int flags)
 	    /* Optional output (here before we update the state machine). */
 	    if (do_print)
 		PRINT_RECORD(flags, offset, rec_type, STR(buffer));
+	    /* Postfix 3.11 maildrop files may have preliminary SIZE record. */
+	    if (strncmp(VSTREAM_PATH(fp), MAIL_QUEUE_MAILDROP "/",
+			sizeof(MAIL_QUEUE_MAILDROP)) == 0)
+		continue;
 	    /* Read the message size/offset for the state machine optimizer. */
 	    if (data_size >= 0 || data_offset >= 0) {
 		msg_warn("file contains multiple size records");
@@ -519,7 +523,7 @@ int     main(int argc, char **argv)
 	    flags |= PC_FLAG_RAW;
 	    break;
 	case 's':
-	    if (!alldig(optarg) || (start_offset = atol(optarg)) <= 0)
+	    if (!alldig(optarg) || (start_offset = atol(optarg)) < 0)
 		msg_fatal("bad offset: %s", optarg);
 	    break;
 	case 'v':
